@@ -178,12 +178,12 @@ def convert_one_gsp_id_to_forecast_sql(
     for forecast in results_for_one_gsp_id.forecasts:
         # add timezone
         target_time = forecast.target_datetime_utc.replace(tzinfo=timezone.utc)
-        forecast_values.append(
-            ForecastValue(
-                target_time=target_time,
-                expected_power_generation_megawatts=forecast.forecast_gsp_pv_outturn_mw,
-            ).to_orm()
-        )
+        f = ForecastValue(
+            target_time=target_time,
+            expected_power_generation_megawatts=forecast.forecast_gsp_pv_outturn_mw,
+        ).to_orm()
+        f.adjust_mw = 0.0
+        forecast_values.append(f)
 
     forecast = ForecastSQL(
         model=ml_model,
